@@ -10,8 +10,8 @@
 #' @return Subset of object of same type as \code{x}. The object is not simplified,
 #'   i.e, no dimensions are dropped as \code{[,,drop = FALSE]} is used.
 #' @export
-dropNamed = function(x, drop) {
-  checkArg(drop, "character", na.ok=FALSE)
+dropNamed = function(x, drop = character(0L)) {
+  assertCharacter(drop, any.missing = FALSE)
   if (length(drop) == 0L)
     return(x)
 
