@@ -1,12 +1,12 @@
 #' Find row- or columnwise the index of the maximal / minimal element in a matrix.
-#' 
+#'
 #' \code{getMaxIndexOfRows} returns the index of the maximal element of each row.
 #' \code{getMinIndexOfRows} returns the index of the minimal element of each row.
 #' \code{getMaxIndexOfCols} returns the index of the maximal element of each col.
 #' \code{getMinIndexOfCols} returns the index of the minimal element of each col.
 #' If a corresponding vector (row or col) is empty, possibly after NA removal, -1 is returned
 #' as index.
-#' 
+#'
 #' @param x [\code{matrix(n,m)}] \cr
 #'   Numerical input matrix.
 #' @param ties.method [\code{character(1)}]\cr
@@ -27,9 +27,9 @@
 #' print(getMinIndexOfRows(x))
 getMaxIndexOfRows = function(x, ties.method="random", na.rm=FALSE) {
   mode(x) = "numeric"
-  ties.method = switch(ties.method, random=1L, first=2L, last=3L, 
+  ties.method = switch(ties.method, random=1L, first=2L, last=3L,
                        stop("Unknown ties method"))
-  checkArg(na.rm, "logical", len=1L, na.ok=FALSE)
+  assertFlag(na.rm)
   .Call(c_getMaxIndexOfRows, x, ties.method, na.rm)
 }
 
@@ -43,7 +43,7 @@ getMinIndexOfRows = function(x, ties.method="random", na.rm=FALSE) {
 #' @rdname getMaxIndexOfRows
 getMaxIndexOfCols = function(x, ties.method="random", na.rm=FALSE) {
   mode(x) = "numeric"
-  ties.method = switch(ties.method, random=1L, first=2L, last=3L, 
+  ties.method = switch(ties.method, random=1L, first=2L, last=3L,
                        stop("Unknown ties method"))
   .Call(c_getMaxIndexOfCols, x, ties.method, na.rm)
 }
